import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';
interface Job {
  id: number;
  title: string;
  company: string;
  location: string;
  type: string;
  salary: string;
  description: string;
}



@Component({
  selector: 'app-page-job-hunting',
  standalone: true,
  imports: [CommonModule,FormsModule],
  templateUrl: './page-job-hunting.html',
  styleUrls: ['./page-job-hunting.scss']
})
export class PageJobHunting {
  searchTerm: string = '';
  selectedType: string = '';
  selectedLocation: string = '';

  constructor(private router: Router) {}

  jobs: Job[] = [
    {
      id: 1,
      title: "前端开发工程师",
      company: "ABC科技有限公司",
      location: "北京",
      type: "技术",
      salary: "15k-25k",
      description: "负责公司产品的前端开发工作，参与需求讨论和技术方案设计。"
    },
    {
      id: 2,
      title: "产品经理",
      company: "XYZ互联网公司",
      location: "上海",
      type: "产品",
      salary: "20k-30k",
      description: "负责产品规划、需求分析和项目管理，协调各方资源推动产品迭代。"
    },
    {
      id: 3,
      title: "UI设计师",
      company: "创意设计工作室",
      location: "深圳",
      type: "设计",
      salary: "12k-20k",
      description: "负责公司产品的界面设计和用户体验优化，输出高质量设计稿。"
    },
    {
      id: 4,
      title: "市场营销专员",
      company: "快消品集团",
      location: "广州",
      type: "市场",
      salary: "8k-15k",
      description: "负责市场推广活动的策划与执行，分析市场数据并提出优化建议。"
    },
    {
      id: 5,
      title: "Java开发工程师",
      company: "金融科技公司",
      location: "杭州",
      type: "技术",
      salary: "18k-30k",
      description: "负责金融系统后端开发，参与架构设计和性能优化。"
    },
    {
      id: 6,
      title: "人力资源专员",
      company: "跨国企业",
      location: "北京",
      type: "人事",
      salary: "10k-18k",
      description: "负责招聘、员工关系管理和人力资源相关事务。"
    },
    {
      id: 7,
      title: "数据分析师",
      company: "电商平台",
      location: "远程",
      type: "技术",
      salary: "15k-25k",
      description: "负责业务数据分析，建立数据模型并提供决策支持。"
    },
    {
      id: 8,
      title: "销售经理",
      company: "医疗器械公司",
      location: "成都",
      type: "销售",
      salary: "底薪+提成",
      description: "负责区域市场开发，维护客户关系并完成销售目标。"
    },
    {
      id: 9,
      title: "财务主管",
      company: "上市公司",
      location: "上海",
      type: "财务",
      salary: "20k-35k",
      description: "负责公司财务核算、报表编制和税务筹划工作。"
    },
    {
      id: 10,
      title: "运维工程师",
      company: "云计算服务商",
      location: "深圳",
      type: "技术",
      salary: "16k-28k",
      description: "负责服务器和网络设备的维护，保障系统稳定运行。"
    }
  ];

  get filteredJobs(): Job[] {
    const searchTerm = this.searchTerm.toLowerCase();
    const selectedType = this.selectedType;
    const selectedLocation = this.selectedLocation;

    return this.jobs.filter(job => {
      const matchesSearch = 
        job.title.toLowerCase().includes(searchTerm) ||
        job.company.toLowerCase().includes(searchTerm) ||
        job.description.toLowerCase().includes(searchTerm);
      
      const matchesType = selectedType === '' || job.type === selectedType;
      const matchesLocation = selectedLocation === '' || job.location === selectedLocation;
      
      return matchesSearch && matchesType && matchesLocation;
    });
  }

  applyForJob(jobId: number): void {
  // 检查简历是否完整
  const resume = localStorage.getItem('userResume');
  if (!resume) {
    if (confirm('您还没有创建简历，是否现在去创建？')) {
      this.router.navigate(['/resume']);
    }
    return;
  }

  const parsedResume = JSON.parse(resume);
  if (!parsedResume.basicInfo.name || !parsedResume.basicInfo.email) {
    if (confirm('您的简历不完整，是否现在去完善？')) {
      this.router.navigate(['/resume']);
    }
    return;
  }

  // 实际应用中这里会调用API提交申请
  console.log(`Applying for job ID: ${jobId} with resume:`, parsedResume);
  
  // 模拟API调用
  setTimeout(() => {
    alert(`已成功申请职位ID: ${jobId}\n我们将通过 ${parsedResume.basicInfo.email} 与您联系`);
    
    // 添加到申请记录
    const applications = JSON.parse(localStorage.getItem('jobApplications') || '[]');
    applications.push({
      jobId,
      date: new Date().toISOString(),
      status: '已提交'
    });
    localStorage.setItem('jobApplications', JSON.stringify(applications));
  }, 1000);
}
  
}