import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Router } from '@angular/router';
import { FaIconComponent } from '@fortawesome/angular-fontawesome';
import { 
  faUser, faEnvelope, faPhone, faGraduationCap, 
  faBriefcase, faPen, faTrash, faPlus, faCheck
} from '@fortawesome/free-solid-svg-icons';

@Component({
  selector: 'app-page-resume',
  standalone: true,
  imports: [CommonModule, FormsModule, FaIconComponent],
  templateUrl: './page-resume.html',
  styleUrls: ['./page-resume.scss']
})
export class PageResume {
  icons = {
    user: faUser,
    email: faEnvelope,
    phone: faPhone,
    education: faGraduationCap,
    experience: faBriefcase,
    edit: faPen,
    delete: faTrash,
    add: faPlus,
    save: faCheck,
    briefcase: faBriefcase
  };

  resume = {
    basicInfo: {
      name: '',
      email: '',
      phone: '',
      position: ''
    },
    education: [] as {
      id: number;
      school: string;
      degree: string;
      major: string;
      startDate: string;
      endDate: string;
    }[],
    experiences: [] as {
      id: number;
      company: string;
      position: string;
      startDate: string;
      endDate: string;
      description: string;
    }[],
    skills: [] as string[]
  };

  newSkill = '';
  isEditing = false;

  constructor(private router: Router) {
    // 从本地存储加载简历数据
    const savedResume = localStorage.getItem('userResume');
    if (savedResume) {
      this.resume = JSON.parse(savedResume);
    }
  }

  addEducation() {
    this.resume.education.push({
      id: Date.now(),
      school: '',
      degree: '',
      major: '',
      startDate: '',
      endDate: ''
    });
  }

  removeEducation(id: number) {
    this.resume.education = this.resume.education.filter(edu => edu.id !== id);
  }

  addExperience() {
    this.resume.experiences.push({
      id: Date.now(),
      company: '',
      position: '',
      startDate: '',
      endDate: '',
      description: ''
    });
  }

  removeExperience(id: number) {
    this.resume.experiences = this.resume.experiences.filter(exp => exp.id !== id);
  }

  addSkill() {
    if (this.newSkill.trim()) {
      this.resume.skills.push(this.newSkill.trim());
      this.newSkill = '';
    }
  }

  removeSkill(index: number) {
    this.resume.skills.splice(index, 1);
  }

  saveResume() {
    localStorage.setItem('userResume', JSON.stringify(this.resume));
    this.isEditing = false;
    alert('简历保存成功！');
  }

  startEditing() {
    this.isEditing = true;
  }

  cancelEditing() {
    if (confirm('确定要取消编辑吗？未保存的更改将丢失。')) {
      const savedResume = localStorage.getItem('userResume');
      if (savedResume) {
        this.resume = JSON.parse(savedResume);
      } else {
        this.resume = {
          basicInfo: { name: '', email: '', phone: '', position: '' },
          education: [],
          experiences: [],
          skills: []
        };
      }
      this.isEditing = false;
    }
  }
}